@@ -30,6 +30,15 @@ from ogr.deprecation import deprecate_and_set_removal
 from ogr.exceptions import OgrException
 from ogr.parsing import parse_git_repo
 
+try:
+    from functools import cached_property
+except ImportError:
+    from functools import lru_cache
+
+    def cached_property(func):  # type: ignore
+        return property(lru_cache()(func))
+
+
 AnyComment = TypeVar("AnyComment", bound="Comment")
 
 
@@ -180,7 +189,12 @@ class Issue:
 
     @staticmethod
     def create(
-        project: Any, title: str, body: str, private: Optional[bool] = None
+        project: Any,
+        title: str,
+        body: str,
+        private: Optional[bool] = None,
+        labels: Optional[List[str]] = None,
+        assignees: Optional[List[str]] = None,
     ) -> "Issue":
         """
         Open new Issue.
@@ -188,6 +202,8 @@ class Issue:
         :param project: Any
         :param title: str
         :param body: str
+        :param labels: list
+        :param assignees: list
         :return: Issue
         """
         raise NotImplementedError()
@@ -604,10 +620,13 @@ class CommitFlag:
             f"edited='{self.edited}')"
         )
 
-    def _state_from_str(self, state: str) -> CommitStatus:
-        if state not in self._states:
-            raise ValueError("non-existing status")
-        return self._states[state]
+    @classmethod
+    def _state_from_str(cls, state: str) -> CommitStatus:
+        raise NotImplementedError()
+
+    @classmethod
+    def _validate_state(cls, state: Union[CommitStatus, str]) -> CommitStatus:
+        raise NotImplementedError()
 
     def _from_raw_commit_flag(self) -> None:
         raise NotImplementedError()
@@ -736,6 +755,13 @@ class GitService:
             raise OgrException(f"Failed to find repository for url: {url}")
         return self.get_project(repo=repo_url.repo, namespace=repo_url.namespace)
 
+    @cached_property
+    def hostname(self) -> Optional[str]:
+        """
+        Hostname of the service.
+        """
+        raise NotImplementedError
+
     @property
     def user(self) -> "GitUser":
         """
@@ -754,13 +780,17 @@ class GitService:
         raise NotImplementedError
 
     def project_create(
-        self, repo: str, namespace: Optional[str] = None
+        self,
+        repo: str,
+        namespace: Optional[str] = None,
+        description: Optional[str] = None,
     ) -> "GitProject":
         """
         Create a new project.
 
         :param repo: str
         :param namespace: Optional[str]
+        :param description: str
         :return: GitProject
         """
         raise NotImplementedError()
@@ -780,6 +810,18 @@ class GitProject:
         self.repo = repo
         self.namespace = namespace
 
+    def delete(self) -> None:
+        """Delete the project."""
+        raise NotImplementedError()
+
+    def exists(self) -> bool:
+        """
+        Check the existence of the repo.
+
+        :return: True if the project exists, False otherwise
+        """
+        raise NotImplementedError()
+
     def is_private(self) -> bool:
         """
         Is this repo private (accessible only by users with permissions)
@@ -993,6 +1035,7 @@ class GitProject:
         body: str,
         private: Optional[bool] = None,
         labels: Optional[List[str]] = None,
+        assignees: Optional[List[str]] = None,
     ) -> Issue:
         """
         Open new Issue.
@@ -1002,6 +1045,7 @@ class GitProject:
         :param body: str
         :param private: bool
         :param labels: [str]
+        :param assignees: [str]
         :return: Issue
         """
         raise NotImplementedError()
