@@ -21,7 +21,7 @@
 # SOFTWARE.
 
 import datetime
-from typing import List, Optional, Match, Any
+from typing import List, Optional, Match, Any, Union
 import warnings
 
 from ogr.abstract import (
@@ -34,6 +34,7 @@ from ogr.abstract import (
     Issue,
     PullRequest,
     CommitFlag,
+    CommitStatus,
 )
 from ogr.deprecation import deprecate_and_set_removal
 from ogr.exceptions import OgrException
@@ -41,8 +42,24 @@ from ogr.parsing import parse_git_repo
 from ogr.read_only import if_readonly, GitProjectReadOnly
 from ogr.utils import search_in_comments, filter_comments
 
+try:
+    from functools import cached_property
+except ImportError:
+    from functools import lru_cache
+
+    def cached_property(func):  # type: ignore
+        return property(lru_cache()(func))
+
 
 class BaseGitService(GitService):
+    @cached_property
+    def hostname(self) -> Optional[str]:
+        """
+        Hostname of the service.
+        """
+        parsed_url = parse_git_repo(potential_url=self.instance_url)
+        return parsed_url.hostname if parsed_url else None
+
     def get_project_from_url(self, url: str) -> "GitProject":
         repo_url = parse_git_repo(potential_url=url)
         if not repo_url:
@@ -368,7 +385,7 @@ class BasePullRequest(PullRequest):
 
     def get_statuses(self) -> List[CommitFlag]:
         commit = self.get_all_commits()[-1]
-        return self.project.get_commit_statuses(commit)
+        return self.target_project.get_commit_statuses(commit)
 
 
 class BaseGitUser(GitUser):
@@ -384,3 +401,25 @@ class BaseIssue(Issue):
 
     def can_close(self, username: str) -> bool:
         return username == self.author or username in self.project.who_can_close_issue()
+
+
+class BaseCommitFlag(CommitFlag):
+    @classmethod
+    def _state_from_str(cls, state: str) -> CommitStatus:
+        if state not in cls._states:
+            raise ValueError("Invalid state given")
+        return cls._states[state]
+
+    @classmethod
+    def _validate_state(cls, state: Union[CommitStatus, str]) -> CommitStatus:
+        if isinstance(state, str):
+            warnings.warn(
+                "Using the string representation of commit states, that will be removed in 0.14.0"
+                " (or 1.0.0 if it comes sooner). Please use CommitStatus enum instead. "
+            )
+            state = cls._state_from_str(state)
+
+        if state not in cls._states.values():
+            raise ValueError("Invalid state given")
+
+        return state
