@@ -24,11 +24,9 @@ import logging
 from typing import Optional, Dict, List, Set, Union
 
 import github
-from github import (
-    UnknownObjectException,
-    Repository,
-    CommitComment as GithubCommitComment,
-)
+from github import UnknownObjectException
+from github.Repository import Repository
+from github.CommitComment import CommitComment as GithubCommitComment
 from github.GitRelease import GitRelease as PyGithubRelease
 
 from ogr.abstract import (
@@ -285,10 +283,16 @@ class GithubProject(BaseGitProject):
         body: str,
         private: Optional[bool] = None,
         labels: Optional[List[str]] = None,
+        assignees: Optional[List[str]] = None,
     ) -> Issue:
         if private:
             raise NotImplementedError("Private issues are not supported by Github")
-        return GithubIssue.create(project=self, title=title, body=body, labels=labels)
+        return GithubIssue.create(
+            project=self, title=title, body=body, labels=labels, assignees=assignees
+        )
+
+    def delete(self) -> None:
+        self.github_repo.delete()
 
     def get_pr_list(self, status: PRStatus = PRStatus.open) -> List[PullRequest]:
         return GithubPullRequest.get_list(project=self, status=status)
@@ -480,7 +484,7 @@ class GithubProject(BaseGitProject):
         return GithubRelease(
             tag_name=raw_release.tag_name,
             url=raw_release.url,
-            created_at=raw_release.created_at,
+            created_at=str(raw_release.created_at),
             tarball_url=raw_release.tarball_url,
             git_tag=git_tag,
             project=self,
@@ -586,6 +590,7 @@ class GithubProject(BaseGitProject):
         return [
             self.service.get_project_from_github_repository(fork)
             for fork in self.github_repo.get_forks()
+            if fork.owner
         ]
 
     def get_web_url(self) -> str:
