@@ -24,7 +24,7 @@ import logging
 from typing import List, Optional, Dict, Set, Union
 
 import gitlab
-from gitlab.v4.objects import Project as GitlabObjectsProject
+from gitlab.v4.objects import GitlabGetError, Project as GitlabObjectsProject
 
 from ogr.abstract import (
     PullRequest,
@@ -120,6 +120,15 @@ class GitlabProject(BaseGitProject):
             logger.debug(f"Project {self.repo}/{user_login} does not exist: {ex}")
         return None
 
+    def exists(self) -> bool:
+        try:
+            _ = self.gitlab_repo
+            return True
+        except GitlabGetError as ex:
+            if "404 Project Not Found" in str(ex):
+                return False
+            raise GitlabAPIException from ex
+
     def is_private(self) -> bool:
         """
         Is this repo private? (accessible only by users with granted access)
@@ -190,6 +199,9 @@ class GitlabProject(BaseGitProject):
     def can_merge_pr(self, username) -> bool:
         return username in self.who_can_merge_pr()
 
+    def delete(self) -> None:
+        self.gitlab_repo.delete()
+
     def _get_collaborators_with_given_access(
         self, access_levels: List[int]
     ) -> List[str]:
@@ -416,9 +428,25 @@ class GitlabProject(BaseGitProject):
         body: str,
         private: Optional[bool] = None,
         labels: Optional[List[str]] = None,
+        assignees: Optional[List[str]] = None,
     ) -> Issue:
+
+        ids = []
+        for user in assignees or []:
+            users_list = self.service.gitlab_instance.users.list(username=user)
+
+            if not users_list:
+                raise GitlabAPIException(f"Unable to find '{user}' username")
+
+            ids.append(str(users_list[0].id))
+
         return GitlabIssue.create(
-            project=self, title=title, body=body, private=private, labels=labels
+            project=self,
+            title=title,
+            body=body,
+            private=private,
+            labels=labels,
+            assignees=ids,
         )
 
     def get_pr(self, pr_id: int) -> PullRequest:
