@@ -222,15 +222,24 @@ class PagureProject(BaseGitProject):
     def get_issue(self, issue_id: int) -> Issue:
         return PagureIssue.get(project=self, id=issue_id)
 
+    def delete(self) -> None:
+        self._call_project_api_raw("delete", method="POST")
+
     def create_issue(
         self,
         title: str,
         body: str,
         private: Optional[bool] = None,
         labels: Optional[List[str]] = None,
+        assignees: Optional[List[str]] = None,
     ) -> Issue:
         return PagureIssue.create(
-            project=self, title=title, body=body, labels=labels, private=private
+            project=self,
+            title=title,
+            body=body,
+            labels=labels,
+            private=private,
+            assignees=assignees,
         )
 
     def get_pr_list(
@@ -307,7 +316,7 @@ class PagureProject(BaseGitProject):
                 return None
         return self._construct_fork_project()
 
-    def exists(self):
+    def exists(self) -> bool:
         response = self._call_project_api_raw()
         return response.ok
 
